# OpenSees Model Generator
![PyPI version](https://badge.fury.io/py/osmg.svg)
![Zenodo](https://zenodo.org/badge/DOI/10.5281/zenodo.7536062.svg)

This Python package aims to help users define, analyze, and post-process 3D models using OpenSees.
The project has recently undergone a massive re-write, which led to the documentation and unit tests being taken offline.
We intend to reinstate them soon.

### External resources

- Visit the OpenSees [homepage](https://opensees.berkeley.edu/) to learn more about the program.
- Explore the [OpenSeesWiki](https://opensees.berkeley.edu/wiki/index.php/Main_Page) for additional resources and documentation.
- Find the source code for OpenSeesPy on its [Github repository](https://github.com/zhuminjie/OpenSeesPy).
- Access the OpenSeesPy documentation [here](https://openseespydoc.readthedocs.io/en/latest/).
